pilas.musica

Package pilas :: Module musica |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.musica

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  import os
    11
    12
    13 -def cargar(ruta):
    14      """Carga un canción para reproducir, donde el argumento ``ruta`` indica cual es el archivo.
    15
    16      Por ejemplo::
    17
    18          >>> musica = pilas.musica.cargar("jazz_loop.ogg")
    19
    20      En caso de éxito retorna el objeto Musica, que se puede
    21      reproducir usando el método ``reproducir()``, por ejemplo::
    22
    23          >>> musica.reproducir(repetir=True)
    24
    25      El directorio de búsqueda del sonido sigue el siguiente orden:
    26
    27          * primero busca en el directorio actual.
    28          * luego en 'data'.
    29          * por último en el directorio estándar de la biblioteca.
    30
    31      En caso de error genera una excepción de tipo IOError.
    32
    33      :param ruta: La ruta al archivo a reproducir.
    34      """
    35      ruta = pilas.utils.obtener_ruta_al_recurso(ruta)
    36      return pilas.mundo.motor.cargar_musica(ruta)
    37